@@ -24,8 +24,6 @@
 
 ;;; Code:
 
-(eval-when-compile (require 'riece-inlines))
-
 (require 'riece-misc)
 (require 'riece-commands)
 
@@ -45,21 +43,29 @@
 	   (concat "^\\(" riece-user-regexp
 		   "\\)\\(\\*\\)?=\\([-+]\\)\\([^ ]+\\)")
 	   (car replies))
-	  (riece-insert-info
-	   (list riece-dialogue-buffer riece-others-buffer)
-	   (concat
-	    (riece-concat-server-name
-	     (format "%s is (%s) [%s, %s]"
-		     (match-string 1 (car replies))
-		     (riece-strip-user-at-host (match-string 4 (car replies)))
-		     (if (match-beginning 2)
-			 "operator"
-		       "not operator")
-		     (if (eq (match-string 3 (car replies)) ?-)
-			 "away"
-		       "not away")))
-	    "\n")))
-      (setq replies (cdr replies)))))
+	  (let ((user (match-string 1 (car replies)))
+		(away (eq (match-string 3 (car replies)) ?-))
+		(user-at-host (match-string 4 (car replies)))
+		(operator (not (null (match-beginning 2)))))
+	    (riece-user-toggle-away user away)
+	    (riece-user-toggle-operator user operator)
+	    (riece-insert-info
+	     (list riece-dialogue-buffer riece-others-buffer)
+	     (concat
+	      (riece-concat-server-name
+	       (format "%s is (%s) [%s, %s]"
+		       user
+		       (riece-strip-user-at-host user-at-host)
+		       (if operator
+			   "operator"
+			 "not operator")
+		       (if away
+			   "away"
+			 "not away")))
+	      "\n"))))
+      (setq replies (cdr replies)))
+  (riece-update-status-indicators)
+  (force-mode-line-update t)))
 
 (defun riece-handle-303-message (prefix number name string)
   (riece-insert-info
@@ -69,17 +75,30 @@
     "\n")))
 
 (defun riece-handle-301-message (prefix number name string)
-  (if (string-match
-       (concat "^\\(" riece-user-regexp "\\) :")
-       string)
+  (when (string-match
+	 (concat "^\\(" riece-user-regexp "\\) :")
+	 string)
+    (let ((user (match-string 1 string))
+	  (message (substring string (match-end 0))))
+      (riece-user-toggle-away user t)
       (riece-insert-info
        (list riece-dialogue-buffer riece-others-buffer)
        (concat
 	(riece-concat-server-name
-	 (format "%s is away: %s"
-		 (match-string 1 string)
-		 (substring string (match-end 0))))
-	"\n"))))
+	 (format "%s is away: %s" user message))
+	"\n")))
+  (riece-update-status-indicators)
+  (force-mode-line-update t)))
+
+(defun riece-handle-305-message (prefix number name string)
+  (riece-user-toggle-away riece-real-nickname nil)
+  (riece-update-status-indicators)
+  (force-mode-line-update t))
+
+(defun riece-handle-306-message (prefix number name string)
+  (riece-user-toggle-away riece-real-nickname t)
+  (riece-update-status-indicators)
+  (force-mode-line-update t))
 
 (defun riece-handle-311-message (prefix number name string)
   (if (string-match
@@ -173,7 +192,7 @@
       (let* ((channel (match-string 1 string))
 	     (visible (match-string 2 string))
 	     (topic (substring string (match-end 0))))
-	(let ((buffer (cdr (riece-identity-assoc-no-server
+	(let ((buffer (cdr (riece-identity-assoc
 			    (riece-make-identity channel)
 			    riece-channel-buffer-alist))))
 	  (riece-insert-info buffer (concat visible " users, topic: "
@@ -198,7 +217,7 @@
 	(while modes
 	  (riece-channel-toggle-mode channel (car modes) (eq toggle ?+))
 	  (setq modes (cdr modes)))
-	(let ((buffer (cdr (riece-identity-assoc-no-server
+	(let ((buffer (cdr (riece-identity-assoc
 			    (riece-make-identity channel)
 			    riece-channel-buffer-alist))))
 	  (riece-insert-info buffer (concat "Mode: " mode-string "\n"))
@@ -210,13 +229,15 @@
 	   (concat
 	    (riece-concat-server-name
 	     (format "Mode for %s: %s" channel mode-string))
-	    "\n"))))))
+	    "\n")))
+	(riece-update-channel-indicator)
+	(force-mode-line-update t))))
 
 (defun riece-handle-set-topic (prefix number name string remove)
   (if (string-match "^\\([^ ]+\\) :" string)
       (let* ((channel (match-string 1 string))
 	     (message (substring string (match-end 0)))
-	     (buffer (cdr (riece-identity-assoc-no-server
+	     (buffer (cdr (riece-identity-assoc
 			   (riece-make-identity channel)
 			   riece-channel-buffer-alist))))
 	(if remove
@@ -244,7 +265,7 @@
   (if (string-match "^\\([^ ]+\\) " string)
       (let* ((channel (match-string 1 string))
 	     (user (substring string (match-end 0)))
-	     (buffer (cdr (riece-identity-assoc-no-server
+	     (buffer (cdr (riece-identity-assoc
 			   (riece-make-identity channel)
 			   riece-channel-buffer-alist))))
 	(riece-insert-info buffer (concat "Inviting " user "\n"))
@@ -265,15 +286,17 @@
 	     (host (match-string 3 string))
 	     (server (match-string 4 string))
 	     (nick (match-string 5 string))
-	     (away (match-string 6 string))
-	     (operator (match-string 7 string))
+	     (away (equal (match-string 6 string) "G"))
+	     (operator (not (null (match-beginning 7))))
 	     (flag (match-string 8 string))
 	     (hops (match-string 9 string))
 	     (name (substring string (match-end 0)))
-	     (buffer (cdr (riece-identity-assoc-no-server
+	     (buffer (cdr (riece-identity-assoc
 			   (riece-make-identity channel)
 			   riece-channel-buffer-alist))))
 	(riece-naming-assert-join nick channel)
+	(riece-user-toggle-away user away)
+	(riece-user-toggle-operator user operator)
 	(riece-insert-info
 	 buffer
 	 (format "%10s = %s (%s) [%s, %s, %s hops, on %s]\n"
@@ -313,7 +336,7 @@
 		   (if operator
 		       "operator"
 		     "not operator")
-		   (if (equal away "G")
+		   (if away
 		       "away"
 		     "not away")
 		   hops
