@@ -28,6 +28,7 @@
 (require 'riece-misc)
 
 (defvar riece-ctcp-ping-time nil)
+(defvar riece-ctcp-additional-clientinfo nil)
 
 (defvar riece-dialogue-mode-map)
 
@@ -35,7 +36,9 @@
   (add-hook 'riece-privmsg-hook 'riece-handle-ctcp-request)
   (add-hook 'riece-notice-hook 'riece-handle-ctcp-response)
   (define-key riece-dialogue-mode-map "\C-cv" 'riece-command-ctcp-version)
-  (define-key riece-dialogue-mode-map "\C-cp" 'riece-command-ctcp-ping))
+  (define-key riece-dialogue-mode-map "\C-cp" 'riece-command-ctcp-ping)
+  (define-key riece-dialogue-mode-map "\C-ca" 'riece-command-ctcp-action)
+  (define-key riece-dialogue-mode-map "\C-cc" 'riece-command-ctcp-clientinfo))
 
 (defun riece-handle-ctcp-request (prefix string)
   (when (and prefix string
@@ -80,7 +83,7 @@
 
 (defun riece-handle-ctcp-version-request (prefix target string)
   (let ((buffer (if (riece-channel-p target)
-		    (cdr (riece-identity-assoc-no-server
+		    (cdr (riece-identity-assoc
 			  (riece-make-identity target)
 			  riece-channel-buffer-alist))))
 	(user (riece-prefix-nickname prefix)))
@@ -102,7 +105,7 @@
 
 (defun riece-handle-ctcp-ping-request (prefix target string)
   (let ((buffer (if (riece-channel-p target)
-		    (cdr (riece-identity-assoc-no-server
+		    (cdr (riece-identity-assoc
 			  (riece-make-identity target)
 			  riece-channel-buffer-alist))))
 	(user (riece-prefix-nickname prefix)))
@@ -124,6 +127,57 @@
 	       target))
       "\n"))))
 
+(defun riece-handle-ctcp-clientinfo-request (prefix target string)
+  (let ((buffer (if (riece-channel-p target)
+		    (cdr (riece-identity-assoc
+			  (riece-make-identity target)
+			  riece-channel-buffer-alist))))
+	(user (riece-prefix-nickname prefix)))
+    (riece-send-string
+     (format "NOTICE %s :\1CLIENTINFO %s\1\r\n"
+	     user
+	     (let (messages)
+	       (mapatoms
+		(lambda (atom)
+		  (let ((case-fold-search t))
+		    (if (and (fboundp atom)
+			     (string-match
+			      "riece-handle-ctcp-\\(.+\\)-request"
+			      (symbol-name atom)))
+			(setq messages
+			      (cons (match-string 1 (symbol-name atom))
+				    messages))))))
+	       (mapconcat #'upcase (append messages
+					   riece-ctcp-additional-clientinfo)
+			  " "))))
+    (riece-insert-change buffer (format "CTCP CLIENTINFO from %s\n" user))
+    (riece-insert-change
+     (if (and riece-channel-buffer-mode
+	      (not (eq buffer riece-channel-buffer)))
+	 (list riece-dialogue-buffer riece-others-buffer)
+       riece-dialogue-buffer)
+     (concat
+      (riece-concat-server-name
+       (format "CTCP CLIENTINFO from %s (%s) to %s"
+	       user
+	       (riece-strip-user-at-host (riece-prefix-user-at-host prefix))
+	       target))
+      "\n"))))
+
+(defun riece-handle-ctcp-action-request (prefix target string)
+  (let ((buffer (if (riece-channel-p target)
+		    (cdr (riece-identity-assoc
+			  (riece-make-identity target)
+			  riece-channel-buffer-alist))))
+	(user (riece-prefix-nickname prefix)))
+    (riece-insert-change buffer (concat user " " string "\n"))
+    (riece-insert-change
+     (if (and riece-channel-buffer-mode
+	      (not (eq buffer riece-channel-buffer)))
+	 (list riece-dialogue-buffer riece-others-buffer)
+       riece-dialogue-buffer)
+     (concat (riece-concat-server-name (concat user " " string)) "\n"))))
+
 (defun riece-handle-ctcp-response (prefix string)
   (when (and prefix string
 	     (riece-prefix-nickname prefix))
@@ -189,6 +243,17 @@
 	       elapsed))
       "\n"))))
 
+(defun riece-handle-ctcp-clientinfo-response (prefix target string)
+  (riece-insert-change
+   (list riece-dialogue-buffer riece-others-buffer)
+   (concat
+    (riece-concat-server-name
+     (format "CTCP CLIENTINFO for %s (%s) = %s"
+	     (riece-prefix-nickname prefix)
+	     (riece-strip-user-at-host (riece-prefix-user-at-host prefix))
+	     string))
+    "\n")))
+
 (defun riece-command-ctcp-version (user)
   (interactive
    (let ((completion-ignore-case t))
@@ -206,6 +271,43 @@
   (riece-send-string (format "PRIVMSG %s :\1PING\1\r\n" user))
   (setq riece-ctcp-ping-time (current-time)))
 
+(defun riece-command-ctcp-clientinfo (user)
+  (interactive
+   (let ((completion-ignore-case t))
+     (list (completing-read
+	    "Channel/User: "
+	    (mapcar #'list (riece-get-users-on-server))))))
+  (riece-send-string (format "PRIVMSG %s :\1CLIENTINFO\1\r\n" user)))
+
+(defun riece-command-ctcp-action (channel action)
+  (interactive
+   (list (if current-prefix-arg
+	     (completing-read
+	      "Channel/User: "
+	      (mapcar #'list riece-current-channels))
+	   riece-current-channel)
+	 (read-string "Action: ")))
+  (if (equal action "")
+      (error "No action"))
+  (riece-send-string (format "PRIVMSG %s :\1ACTION %s\1\r\n"
+			     (riece-identity-prefix channel)
+			     action))
+  (let ((buffer (cdr (riece-identity-assoc
+		      (riece-make-identity channel)
+		      riece-channel-buffer-alist))))
+    (riece-insert-change
+     buffer
+     (concat (riece-identity-prefix (riece-current-nickname)) " " action "\n"))
+    (riece-insert-change
+     (if (and riece-channel-buffer-mode
+	      (not (eq buffer riece-channel-buffer)))
+	 (list riece-dialogue-buffer riece-others-buffer)
+       riece-dialogue-buffer)
+     (concat
+      (riece-concat-server-name
+       (concat (riece-identity-prefix (riece-current-nickname)) " " action))
+      "\n"))))
+
 (provide 'riece-ctcp)
 
-;;; riece-ctcp.el ends here
\ No newline at end of file
+;;; riece-ctcp.el ends here
