@@ -208,12 +208,7 @@ way is to put Riece variables on .emacs or file loaded from there."
   :group 'riece-looks)
 
 (defcustom riece-default-freeze nil
-  "If non nil, channel buffer local freeze flag is on at starting."
-  :type 'boolean
-  :group 'riece-looks)
-
-(defcustom riece-default-own-freeze nil
-  "If non nil, channel buffer local own freeze flag is on at starting."
+  "Channel buffer local freeze flag is on at starting."
   :type 'boolean
   :group 'riece-looks)
 
@@ -229,8 +224,13 @@ way is to put Riece variables on .emacs or file loaded from there."
   :group 'riece-options)
 
 (defcustom riece-quit-message nil
-  "Default signoff message."
-  :type '(radio (string :tag "Signoff message"))
+  "Default quit message."
+  :type '(radio (string :tag "Quit message"))
+  :group 'riece-options)
+
+(defcustom riece-away-message nil
+  "Default away message."
+  :type '(radio (string :tag "Away message"))
   :group 'riece-options)
 
 (defcustom riece-gather-channel-modes t
