@@ -23,8 +23,6 @@
 
 ;;; Code:
 
-(eval-when-compile (require 'riece-inlines))	;string-assoc-ignore-case, etc.
-
 (require 'riece-identity)
 
 (defconst riece-user-regexp
@@ -34,44 +32,52 @@
 (defun riece-find-user (name)
   "Get a user object named NAME from the server buffer."
   (riece-with-server-buffer
-   (let ((symbol (intern-soft (downcase (riece-identity-prefix name))
+   (let ((symbol (intern-soft (riece-identity-canonicalize-prefix
+			       (riece-identity-prefix name))
 			      riece-obarray)))
      (if symbol
 	 (symbol-value symbol)))))
 
 (defun riece-forget-user (name)
   (riece-with-server-buffer
-   (let ((symbol (intern-soft (downcase (riece-identity-prefix name)))))
+   (let ((symbol (intern-soft (riece-identity-canonicalize-prefix
+			       (riece-identity-prefix name)))))
      (when symbol
        (makunbound symbol)
        (unintern (symbol-name symbol) riece-obarray)))))
 
 (defun riece-rename-user (old-name new-name)
   (riece-with-server-buffer
-   (unless (equal (downcase (riece-identity-prefix old-name))
-		  (downcase (riece-identity-prefix new-name)))
-     (let ((symbol (intern-soft (downcase (riece-identity-prefix old-name))
+   (unless (equal (riece-identity-canonicalize-prefix
+		   (riece-identity-prefix old-name))
+		  (riece-identity-canonicalize-prefix
+		   (riece-identity-prefix new-name)))
+     (let ((symbol (intern-soft (riece-identity-canonicalize-prefix
+				 (riece-identity-prefix old-name))
 				riece-obarray)))
        (when symbol
-	 (set (intern (downcase (riece-identity-prefix new-name))
+	 (set (intern (riece-identity-canonicalize-prefix
+		       (riece-identity-prefix new-name))
 		      riece-obarray)
 	      (symbol-value symbol))
 	 (makunbound symbol)
 	 (unintern (symbol-name symbol) riece-obarray))))))
 
-(defun riece-make-user (&optional channels user-at-host modes away)
+(defun riece-make-user (&optional channels user-at-host modes away operator)
   "Make an instance of user object.
 Arguments are appropriate to joined channels, user-at-host, mode, and
 away status, respectively."
-  (vector channels user-at-host modes away))
+  (vector channels user-at-host modes away operator))
 
 (defun riece-get-user (name)
   (riece-with-server-buffer
-   (let ((symbol (intern-soft (downcase (riece-identity-prefix name))
+   (let ((symbol (intern-soft (riece-identity-canonicalize-prefix
+			       (riece-identity-prefix name))
 			      riece-obarray)))
      (if symbol
 	 (symbol-value symbol)
-       (set (intern (downcase (riece-identity-prefix name)) riece-obarray)
+       (set (intern (riece-identity-canonicalize-prefix
+		     (riece-identity-prefix name)) riece-obarray)
 	    (riece-make-user))))))
 
 (defun riece-user-channels (user)
@@ -90,6 +96,10 @@ away status, respectively."
   "Return t, if USER has been marked as away."
   (aref user 3))
 
+(defun riece-user-operator (user)
+  "Return t, if USER has operator privilege."
+  (aref user 4))
+
 (defun riece-user-set-channels (user value)
   "Set the joined channels of USER to VALUE."
   (aset user 0 value))
@@ -106,6 +116,10 @@ away status, respectively."
   "Set the away status of USER to VALUE."
   (aset user 3 value))
 
+(defun riece-user-set-operator (user value)
+  "Set the operator status of USER to VALUE."
+  (aset user 4 value))
+
 (defun riece-user-get-channels (&optional name)
   (riece-user-channels
    (riece-get-user (or name riece-real-nickname))))
@@ -122,6 +136,10 @@ away status, respectively."
   (riece-user-away
    (riece-get-user (or name riece-real-nickname))))
 
+(defun riece-user-get-operator (&optional name)
+  (riece-user-operator
+   (riece-get-user (or name riece-real-nickname))))
+
 (defun riece-user-toggle-channel (name channel flag)
   "Add or remove the joined channel of user."
   (let* ((user (riece-get-user (or name (riece-current-nickname))))
@@ -142,6 +160,14 @@ away status, respectively."
       (if (memq mode modes)
 	  (riece-user-set-modes user (delq mode modes))))))
 
+(defun riece-user-toggle-away (name flag)
+  (riece-user-set-away
+   (riece-get-user (or name (riece-current-nickname))) flag))
+
+(defun riece-user-toggle-operator (name flag)
+  (riece-user-set-operator
+   (riece-get-user (or name (riece-current-nickname))) flag))
+
 (provide 'riece-user)
 
 ;;; riece-user.el ends here
