@@ -24,8 +24,6 @@
 
 ;;; Code:
 
-(eval-when-compile (require 'riece-inlines))
-
 (if (featurep 'xemacs)
     (require 'riece-xemacs)
   (require 'riece-emacs))
@@ -199,7 +197,6 @@ If optional argument SAFE is nil, overwrite previous definitions."
   (riece-define-keys riece-channel-list-mode-map
     ">" riece-command-next-channel
     "<" riece-command-previous-channel
-    "u" riece-command-unread-channel
     "o" other-window
     "c" riece-command-select-command-buffer)
 
@@ -288,17 +285,20 @@ For a list of the generic commands type \\[riece-command-generic] ? RET.
   (interactive)
   (kill-all-local-variables)
 
-  (setq major-mode 'riece-command-mode
+  (setq riece-away-indicator "-"
+	riece-operator-indicator "-"
+	major-mode 'riece-command-mode
 	mode-name "Commands"
-	riece-away-indicator "-"
-	riece-freeze-indicator "-"
-	riece-own-freeze-indicator "-"
 	mode-line-buffer-identification
 	(riece-mode-line-buffer-identification
 	 '("Riece: "
-	   mode-line-modified
 	   riece-away-indicator
-	   "-- " riece-current-channel " " riece-real-nickname)))
+	   riece-operator-indicator
+	   riece-freeze-indicator
+	   " "
+	   riece-user-indicator
+	   " "
+	   riece-current-channel)))
   (riece-simplify-mode-line-format)
   (use-local-map riece-command-mode-map)
 
@@ -320,28 +320,24 @@ Instead, these commands are available:
   (kill-all-local-variables)
 
   (make-local-variable 'riece-freeze)
-  (make-local-variable 'riece-freeze-indicator)
-  (make-local-variable 'riece-own-freeze)
-  (make-local-variable 'riece-own-freeze-indicator)
   (make-local-variable 'tab-stop-list)
 
   (setq riece-freeze riece-default-freeze
-	riece-freeze-indicator (if riece-freeze "F" "-")
-	riece-own-freeze riece-default-own-freeze
-	riece-own-freeze-indicator (if riece-own-freeze "M" "-")
-
+	riece-away-indicator "-"
+	riece-operator-indicator "-"
 	major-mode 'riece-dialogue-mode
 	mode-name "Dialogue"
 	mode-line-buffer-identification
 	(riece-mode-line-buffer-identification
 	 '("Riece: "
-	   mode-line-modified
 	   riece-away-indicator
+	   riece-operator-indicator
 	   riece-freeze-indicator
-	   riece-own-freeze-indicator
-	   " " riece-channel-list-indicator " "))
+	   " "
+	   riece-channel-list-indicator " "))
 	buffer-read-only t
 	tab-stop-list riece-tab-stop-list)
+  (riece-update-status-indicators)
   (riece-simplify-mode-line-format)
   (use-local-map riece-dialogue-mode-map)
   (buffer-disable-undo)
@@ -363,10 +359,9 @@ Instead, these commands are available:
   (setq mode-line-buffer-identification
 	(riece-mode-line-buffer-identification
 	 '("Riece: "
-	   mode-line-modified
 	   riece-away-indicator
+	   riece-operator-indicator
 	   riece-freeze-indicator
-	   riece-own-freeze-indicator
 	   " "
 	   riece-channel-indicator))))
 
@@ -389,9 +384,8 @@ All normal editing commands are turned off.
 Instead, these commands are available:
 \\{riece-user-list-mode-map}"
   (kill-all-local-variables)
-  (setq mode-line-modified "--- "
-        major-mode 'riece-user-list-mode
-        mode-name "Riece Channel member"
+  (setq major-mode 'riece-user-list-mode
+        mode-name "User list"
 	mode-line-buffer-identification
 	(riece-mode-line-buffer-identification
 	 '("Riece: " riece-channel-indicator " "))
@@ -415,8 +409,7 @@ Instead, these commands are available:
 
 (defun riece-load-and-build-addon-dependencies (addons)
   (let ((load-path (cons riece-addon-directory load-path))
-	dependencies
-	pointer)
+	dependencies)
     (while addons
       (require (car addons))		;error will be reported here
       (let* ((requires
